{ config, pkgs, lib, ... }:
let
  stylix = import ./stylix.nix { inherit pkgs; };

in {

  home.packages = with pkgs; [ wofi-emoji ];

  programs.wofi = {
    enable = true;

    settings = {
      # global layout
      width = "50%";
      height = "50%";
      orientation = "vertical";
      hide_scroll = true;
      line_wrap = "off";
      dynamic_lines = true;

      # search behaviour
      matching = "fuzzy";
      single_click = true;


      show = "drun";
      prompt = "Launch...";
      # normal_window = true;
      layer = "top";
      term = "foot";
      halign = "fill";

      # Rich rendering
      allow_markup = true;
      allow_images = true;
      image_size = 24;


      exec_search = false;
      hide_search = false;
      parse_search = false;
      insensitive = true;
      no_actions = true;


      filter_rate = 100;
      key_expand = "Tab";
      key_exit = "Escape";

    };


    style = ''
      * {
        font-family: ${stylix.stylix.fonts.sansSerif.name};
        font-size: ${builtins.toString (stylix.stylix.fonts.sizes.applications + 10)}px;
        color: ${stylix.stylix.base16Scheme.base04};
        background: transparent;
      }

      #window {
        background: rgba(41, 46, 66, 0.5);
        margin: auto;
        padding: 10px;
      }

      #input {
        padding: 10px;
        margin-bottom: 10px;
        border-radius: 15px;
      }

      #outer-box {
        padding: 20px;
      }

      #img {
        margin-right: 6px;
      }

      #entry {
        padding: 10px;
        border-radius: 15px;
      }

      #entry:selected {
        background-color: #2e3440;
      }

      #text {
        margin: 2px;
      }
    '';
  };
}
